from_path

Function from_path 

pub fn from_path<T: AsRef<Path>>(path: T) -> FromFile 
Creates an input handle based on the provided path.

To create an input handle based on an optional path, see from_optional_path.